==> qtjambi-xml-debuginfo-linux-x64-5.15.23.jar: sources/QtJambiXml/QDomCharacterData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomCharacterData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomCharacterData")
    QDomCharacterData *_ptr = reinterpret_cast<QDomCharacterData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomCharacterData()
void __qt_construct_QDomCharacterData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCharacterData()")
    Q_UNUSED(__java_arguments)
    QDomCharacterData *__qt_this = new(__qtjambi_ptr) QDomCharacterData();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomCharacterData::QDomCharacterData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_initialize_1native__Lio_qt_xml_QDomCharacterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCharacterData::QDomCharacterData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCharacterData, sizeof(QDomCharacterData), typeid(QDomCharacterData), 0, false, &deleter_QDomCharacterData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomCharacterData(QDomCharacterData)
void __qt_construct_QDomCharacterData_cref_QDomCharacterData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCharacterData(QDomCharacterData)")
    jobject x0 = __java_arguments[0].l;
    const QDomCharacterData& __qt_x0 = qtjambi_cast<const QDomCharacterData&>(__jni_env, x0);
    QDomCharacterData *__qt_this = new(__qtjambi_ptr) QDomCharacterData(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomCharacterData::QDomCharacterData(QDomCharacterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_initialize_1native__Lio_qt_xml_QDomCharacterData_2Lio_qt_xml_QDomCharacterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCharacterData::QDomCharacterData(QDomCharacterData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCharacterData_cref_QDomCharacterData, sizeof(QDomCharacterData), typeid(QDomCharacterData), 0, false, &deleter_QDomCharacterData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomCharacterData
void __qt_destruct_QDomCharacterData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomCharacterData")
    reinterpret_cast<QDomCharacterData*>(ptr)->~QDomCharacterData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomCharacterData::appendData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_appendData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::appendData(QString)", __this_nativeId)
        QString __qt_arg0 = qtjambi_cast<QString>(__jni_env, arg0);
        __qt_this->appendData(__qt_arg0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::data()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::data()const", __this_nativeId)
        QString __qt_return_value = __qt_this->data();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomCharacterData::deleteData(ulong,ulong)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_deleteData_1native_1unsigned_1long_1unsigned_1long__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::deleteData(ulong,ulong)", __this_nativeId)
        __qt_this->deleteData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::insertData(ulong,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_insertData_1native_1unsigned_1long_1cref_1QString__JILjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jstring arg1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::insertData(ulong,QString)", __this_nativeId)
        QString __qt_arg1 = qtjambi_cast<QString>(__jni_env, arg1);
        __qt_this->insertData(static_cast<unsigned long>(offset0), __qt_arg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::length()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_length_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::length()const", __this_nativeId)
        __java_return_value = __qt_this->length();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomCharacterData::operator=(QDomCharacterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_assign_1native_1cref_1QDomCharacterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::operator=(QDomCharacterData)", __this_nativeId)
        const QDomCharacterData& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomCharacterData>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::replaceData(ulong,ulong,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_replaceData_1native_1unsigned_1long_1unsigned_1long_1cref_1QString__JIILjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1,
 jstring arg2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::replaceData(ulong,ulong,QString)", __this_nativeId)
        QString __qt_arg2 = qtjambi_cast<QString>(__jni_env, arg2);
        __qt_this->replaceData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1), __qt_arg2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::setData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_setData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::setData(QString)", __this_nativeId)
        QString __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        __qt_this->setData(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::substringData(ulong,ulong)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_substringData_1native_1unsigned_1long_1unsigned_1long__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::substringData(ulong,ulong)", __this_nativeId)
        QString __qt_return_value = __qt_this->substringData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomCharacterData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomCharacterData>("QDomCharacterData", "io/qt/xml/QDomCharacterData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomCharacterData, {
        ConstructorInfo(&__qt_construct_QDomCharacterData, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomCharacterData_cref_QDomCharacterData, "Lio/qt/xml/QDomCharacterData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomCharacterData);
    registerMetaType<QDomCharacterData>("QDomCharacterData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiXml/QDomCharacterData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomCharacterData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomCharacterData")
    QDomCharacterData *_ptr = reinterpret_cast<QDomCharacterData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomCharacterData()
void __qt_construct_QDomCharacterData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCharacterData()")
    Q_UNUSED(__java_arguments)
    QDomCharacterData *__qt_this = new(__qtjambi_ptr) QDomCharacterData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDomCharacterData(QDomCharacterData)
void __qt_construct_QDomCharacterData_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomCharacterData(QDomCharacterData)")
    jobject x0 = __java_arguments[0].l;
    const QDomCharacterData& __qt_x0 = qtjambi_cast<const QDomCharacterData& >(__jni_env, x0);
    QDomCharacterData *__qt_this = new(__qtjambi_ptr) QDomCharacterData(__qt_x0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDomCharacterData
void __qt_destruct_QDomCharacterData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomCharacterData")
    reinterpret_cast<QDomCharacterData*>(ptr)->~QDomCharacterData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomCharacterData::QDomCharacterData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_initialize_1native__Lio_qt_xml_QDomCharacterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCharacterData::QDomCharacterData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCharacterData_0, sizeof(QDomCharacterData), typeid(QDomCharacterData), false, &deleter_QDomCharacterData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::QDomCharacterData(QDomCharacterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_initialize_1native__Lio_qt_xml_QDomCharacterData_2Lio_qt_xml_QDomCharacterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomCharacterData::QDomCharacterData(QDomCharacterData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomCharacterData_1, sizeof(QDomCharacterData), typeid(QDomCharacterData), false, &deleter_QDomCharacterData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::appendData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_appendData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::appendData(QString)", __qt_this)
        QString  __qt_arg0 = qtjambi_cast<QString >(__jni_env, arg0);
        __qt_this->appendData(__qt_arg0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::data()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::data()const", __qt_this)
        QString __qt_return_value = __qt_this->data();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomCharacterData::deleteData(ulong,ulong)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_deleteData_1native_1unsigned_1long_1unsigned_1long__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::deleteData(ulong,ulong)", __qt_this)
        __qt_this->deleteData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::insertData(ulong,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_insertData_1native_1unsigned_1long_1cref_1QString__JILjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jstring arg1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::insertData(ulong,QString)", __qt_this)
        QString  __qt_arg1 = qtjambi_cast<QString >(__jni_env, arg1);
        __qt_this->insertData(static_cast<unsigned long>(offset0), __qt_arg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::length()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_length_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::length()const", __qt_this)
        __java_return_value = __qt_this->length();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomCharacterData::operator=(QDomCharacterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_assign_1native_1cref_1QDomCharacterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::operator=(QDomCharacterData)", __qt_this)
        const QDomCharacterData& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomCharacterData>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::replaceData(ulong,ulong,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_replaceData_1native_1unsigned_1long_1unsigned_1long_1cref_1QString__JIILjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1,
 jstring arg2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::replaceData(ulong,ulong,QString)", __qt_this)
        QString  __qt_arg2 = qtjambi_cast<QString >(__jni_env, arg2);
        __qt_this->replaceData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1), __qt_arg2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::setData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_setData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::setData(QString)", __qt_this)
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        __qt_this->setData(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomCharacterData::substringData(ulong,ulong)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_substringData_1native_1unsigned_1long_1unsigned_1long__JII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0,
 jint count1)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomCharacterData::substringData(ulong,ulong)", __qt_this)
        QString __qt_return_value = __qt_this->substringData(static_cast<unsigned long>(offset0), static_cast<unsigned long>(count1));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomCharacterData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomCharacterData *__qt_this = QtJambiAPI::objectFromNativeId<QDomCharacterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomCharacterData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomCharacterData>("QDomCharacterData", "io/qt/xml/QDomCharacterData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomCharacterData, {
        ConstructorInfo(&__qt_construct_QDomCharacterData_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomCharacterData_1, "Lio/qt/xml/QDomCharacterData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomCharacterData);
    registerMetaType<QDomCharacterData>("QDomCharacterData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
